/*  Copyright (C) CZ.NIC, z.s.p.o. and contributors
 *  SPDX-License-Identifier: GPL-2.0-or-later
 *  For more information, see <https://www.knot-dns.cz/>
 */

/*!
 * \file
 *
 * Convenient header to include all library modules.
 */

#pragma once

#include <libdnssec/binary.h>
#include <libdnssec/crypto.h>
#include <libdnssec/digest.h>
#include <libdnssec/error.h>
#include <libdnssec/key.h>
#include <libdnssec/keyid.h>
#include <libdnssec/keystore.h>
#include <libdnssec/keytag.h>
#include <libdnssec/nsec.h>
#include <libdnssec/pem.h>
#include <libdnssec/random.h>
#include <libdnssec/sign.h>
#include <libdnssec/tsig.h>
